<?php
//
// +---------------------------------------------------------------------------+
// | Topic Chameleon Hack (chameleon v0.01) for Geeklog                        |
// +---------------------------------------------------------------------------+
// | option2.php                                                               |
// +---------------------------------------------------------------------------+
// | This hack will allow theme changing when accessing different topics,      |
// | accessing an individual story under a topic either directly or through    |
// | the "read more" link, plus accessing or responding to comments tied       |
// | to a story.                                                               |
// |                                                                           |
// | In this version, theme names are manually set to any name not necessarily |
// | the same as the topic ids.  Each time a new topic is added besides        |
// | creating new theme files you must also manually add the corresponding     |
// | theme name to this file.  The theme will revert to the system default or  |
// | user's selection for missing topic theme directories.                     |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2003 by DoYourDD (geek@doyourdd.com)                        |
// |                                                                           |
// | function setDefaultTheme contains a modified version of the set theme     |
// | code from lib-common.php which is Copyrighted by Tony Bibbs               |
// | (tony@tonybibbs.com), Mark Limburg (mlimburg@users.sourceforge.net),      |
// | Jason Wittenburg (jwhitten@securitygeeks.com), and Dirk Haun              |
// | (dirk@haun-online.de)                                                     |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+
//

// +-----------------------+
// | set configuration     |
// +-----------------------+

// name of your default theme
$h_default_theme = 'classic';

// directory name where the new dynamic partial themes are located
$h_directory_name = 'chameleon';

// path going to the directory where the new partial dynamic themes are located
$h_path_dynamic_themes = $_CONF['path_html'] . $h_directory_name . '/';

// theme list indexed by topic id (e.g. team1) set to the desired theme (e.g. champions)
$h_theme_list = array();
$h_theme_list['team1']  = 'champions';
$h_theme_list['team2']  = 'winsomelosesome';
$h_theme_list['team3']  = 'alwaysdeadlast';

// +-----------------------+
// | end configuration     |
// +-----------------------+


// sets the theme either to system default or the user's selection
function setDefaultTheme($h_default_theme) 
{
    global $_CONF, $_USER;

    // check whether user themes are allowed
    if ($_CONF['allow_user_themes'] == 1) {

        // if empty, set theme to cookie value or system default
        if (empty($_USER['theme'])) {

            // set theme to cookie if directory can be opened
            if (isset($HTTP_COOKIE_VARS[$_CONF['cookie_theme']]) && ($handle = @opendir( $_CONF['path_themes'] . $HTTP_COOKIE_VARS[$_CONF['cookie_theme']]))) {
                $_USER['theme']       = $HTTP_COOKIE_VARS[$_CONF['cookie_theme']];
                $_CONF['theme']       = $_USER['theme'];
                $_CONF['path_layout'] = $_CONF['path_themes'] . $_CONF['theme'] . '/';
                $_CONF['layout_url']  = $_CONF['site_url'] . '/layout/' . $_CONF['theme'];
                closedir($handle);
            }
            // otherwise set it to the system default
            else {
                $_CONF['theme']       = $h_default_theme;
                $_USER['theme']       = $_CONF['theme']; 
                $_CONF['path_layout'] = $_CONF['path_themes'] . $_CONF['theme'] . '/';
                $_CONF['layout_url']  = $_CONF['site_url'] . '/layout/' . $_CONF['theme'];
            }
        } // end if

        // if not empty, set theme to user theme or system default
        else {
            // set theme to user theme if directory can be opened
            if ($handle = @opendir($_CONF['path_themes'] . $_USER['theme'])) {
                $_CONF['theme'] = $_USER['theme'];
                $_CONF['path_layout'] = $_CONF['path_themes'] . $_CONF['theme'] . '/';
                $_CONF['layout_url'] = $_CONF['site_url'] . '/layout/' . $_CONF['theme'];
                closedir($handle);
            }
            // otherwise set it to the system default
            else {
                $_CONF['theme'] = $h_default_theme;
                $_USER['theme'] = $_CONF['theme']; 
                $_CONF['path_layout'] = $_CONF['path_themes'] . $_CONF['theme'] . '/';
                $_CONF['layout_url'] = $_CONF['site_url'] . '/layout/' . $_CONF['theme'];
            }
        } // end if
    } // end if

    // if no user themes are allowed set the theme to system default
    else {
        $_CONF['theme']       = $h_default_theme;
        $_USER['theme']       = $_CONF['theme']; 
        $_CONF['path_layout'] = $_CONF['path_themes'] . $_CONF['theme'] . '/';
        $_CONF['layout_url']  = $_CONF['site_url'] . '/layout/' . $_CONF['theme'];
    }  // end else

} // end function setDefaultTheme

// check if story id is set - $story (from article.php) or $sid (from comments.php)
if (isset($story) || isset($sid)) {

    // pull the story's topic id from the database
    if (isset($story))
        $h_result = DB_query("SELECT tid FROM {$_TABLES['stories']} WHERE sid = '$story'");
    else
        $h_result = DB_query("SELECT tid FROM {$_TABLES['stories']} WHERE sid = '$sid'");

    // set the $topic variable only if a valid story/topic is found
    $h_numrows = DB_numRows($h_result);
    if ($h_numrows > 0) {
        $h_theme = DB_fetchArray($h_result); 
        $topic   = $h_theme['tid']; 
    }
}

// set the theme based on the topic chosen
if (isset($topic)) {

    // check whether the topic has an associated theme
    if (isset($h_theme_list[$topic])) {

        // set theme to the topic if the directory exists and can be opened
        $h_theme_path = $h_path_dynamic_themes . $h_theme_list[$topic] . '/';
        if ($handle = @opendir ($h_theme_path)) {
            $_CONF['theme']  = $h_theme_list[$topic];
            $_USER['theme'] = $_CONF['theme']; 
            $_CONF['path_layout'] = $h_path_dynamic_themes . $_CONF['theme'] . '/';
            $_CONF['layout_url'] = $_CONF['site_url'] . '/' . $h_directory_name . '/' . $_CONF['theme'];
            closedir($handle);

        }
        // otherwise set theme to system default or the user's selection
        else {
            setDefaultTheme($h_default_theme); 

        }
    }
    // if no associated theme set it to system default or the user's selection
    else {
        setDefaultTheme($h_default_theme); 
    }
}

// for non-topic areas set the theme to system default or the user's selection
else {
    setDefaultTheme($h_default_theme);
}
?>